@@ -4,7 +4,7 @@ use 5.008008;
 use strict;
 use warnings;
 
-our $VERSION = '0.081';
+our $VERSION = '0.09';
 
 my $allow_new_methods = 0;
 
@@ -15,24 +15,20 @@ sub new {
   my $self = {@_};
   bless($self, $class);
 
-  $self->initialize;
-
-  return $self;
-}
-
-sub initialize {
-  my $self = shift;
-
   if (!$self->{module}) {
     require Carp;
     Carp::croak("No module name provided to mock");
   }
 
-  my $module = $self->{module} . '.pm';
-  $module =~ s/::/\//g;
-  require $module;
+  if (!$self->{no_load}) {
+    my $module = $self->{module} . '.pm';
+    $module =~ s/::/\//g;
+    require $module;
+  }
 
-  $allow_new_methods = 1 if $self->{allow_new_methods};
+  $allow_new_methods = 1 if $self->{allow_new_methods} || $self->{no_load};
+
+  return $self;
 }
 
 sub add {
@@ -42,10 +38,13 @@ sub add {
 
   return if $ENV{TEST_MOCK_SIMPLE_DISABLE};
 
-  if (!$name || !$sub) {
+  if (!$name) {
     require Carp;
-    Carp::croak("No method name provided to mock") unless $name;
-    Carp::croak("No sub ref provided to mock") unless $sub;
+    Carp::croak("No method name provided to mock");
+  }
+  if (!$sub) {
+    require Carp;
+    Carp::croak("No sub ref provided to mock");
   }
 
   if (!$allow_new_methods) {
@@ -146,6 +145,21 @@ should stop mistyping method names when attempting to mock existing methods.
 
 =back
 
+=over 4
+
+=item no_load
+
+Default behavior is to load the real module before overriding individual methods.
+
+If this is not desired set no_load to 1 which will stop this from happening.
+
+If set then you are required to mock the whole module (or at least every command
+required for code to work).
+
+Setting no_load to 1 will force allow_new_methods to 1 as well.
+
+=back
+
 =item add
 
 This allows for the creation of a new method (subroutine) that will override the
